# Changelog

## v0.1.0 - 2024-03-17 JST

First release

### Features

- Define two decorator functions.
  - `setup_only` outputs message if user run with unexpected builders.
  - `emit_only` skip proc if user run with unexpected builders.

## v0.0.0 - 2024-03-16 JST
